@@ -1,5 +1,6 @@
 import os
 import torch
+from random import randint
 
 from lightwood.config.config import CONFIG
 
@@ -10,21 +11,14 @@ def get_devices():
         available_devices = torch.cuda.device_count()
 
         if available_devices > 1:
-            round_robin = os.environ.get('ROUND_ROBIN_GPU', False)
-            if round_robin in ['1', 'true', 'True', True]:
-                round_robin = True
-            else:
-                round_robin = False
-
-            if round_robin:
-                current_gpu = int(os.environ.get('ROUND_ROBIN_GPU_CURRENT', '0'))
-                device_str = 'cuda:' + str(current_gpu % available_devices)
-                os.envrion['ROUND_ROBIN_GPU_CURRENT'] = (str(current_gpu+1))
+            if os.environ.get('RANDOM_GPU', False) in ['1', 'true', 'True', True, 1]:
+                device_str = 'cuda:' + str(randint(0,available_devices-1))
+                available_devices = 1
     else:
         device_str = "cpu"
         available_devices = 1
 
-    if CONFIG.USE_DEVICE is not None:
+    if CONFIG.USE_DEVICE is not None and os.environ.get('RANDOM_GPU', False) not in ['1', 'true', 'True', True, 1]:
         device_str = CONFIG.USE_DEVICE
         if device_str != 'cuda':
             available_devices = 1
